@@ -27,8 +27,11 @@ speMCA_varsup <- function(mca, df) {
     Reduce(function(acc, cur) {
         for (name in names(acc)) {
             if (name == "weight") next
-            acc[[name]] <- dplyr::bind_rows(acc[[name]], cur[[name]])
+            acc[[name]] <- dplyr::bind_rows(
+                data.frame(acc[[name]]),
+                data.frame(cur[[name]])
+            )
         }
         acc
     }, res)
-}
\ No newline at end of file
+}
